/*
 *   logtool - a logfile parsing/monitoring/manipulation utility
 *
 *   Copyright (C) Y2K (2000) A.L.Lambert
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2, or (at your option)
 *   any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "includes.h"

void lto_raw() {
	/* Open up stdin and read the input one line at a time till EOF */
	while(fgets(event.raw, LSIZE, stdin) != NULL) {
		/* Make sure the format of the input is correct */
		if(lt_fmtcheck(event.raw) == -1) {
			continue;
		} 
		/* Print that sucker */
		printf("%s", event.raw);
		fflush(stdout);
	}
}
