/*
 *   logtool - a logfile parsing/monitoring/manipulation utility
 *
 *   Copyright (C) Y2K (2000) A.L.Lambert
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2, or (at your option)
 *   any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/* Yee ole includes (I put this all in one file for my sanity) */
#include "includes.h"

/* there ain't no such thing as this module yet. Bummer, eh?	*/

/*
 * There is no such module as of yet.  It is in the works for version 1.2.0
 * 
 * Try not to look so dissappointed, eh? :P
 * 
 */
 
short int ltm_syslog() { 

	char msg_tmp[LSIZE];
	
	/* Figure out what color (red/green/yellow) this message should be */
	lt_set_event_color();
	mod_premsg_setup();
	
	/* Always print the message from the log event */
	sprintf(msg_tmp, " %s%s%s", event.pcolor, event.message, "\033e");

	strcat(event.pmsg, msg_tmp);	
	
	return 0;
}
